@@ -44,6 +44,13 @@ class VivadoEmulation(VivadoTCLGenerator):
         # set define variables
         self.add_project_defines(content=self.target.content, fileset='[current_fileset]')
 
+        # specify the level of flattening to use
+        self.set_property(
+            'STEPS.SYNTH_DESIGN.ARGS.FLATTEN_HIERARCHY',
+            self.target.prj_cfg.cfg.flatten_hierarchy,
+            '[get_runs synth_1]'
+        )
+
         # append user constraints
         for xdc_file in self.target.content.xdc_files:
             for file in xdc_file.files:
@@ -151,4 +158,4 @@ class VivadoEmulation(VivadoTCLGenerator):
         self.target.ctrl_api._setup_ctrl(server_addr=server_addr)
 
         # return ctrl object to user for further interactive commands
-        return self.target.ctrl_api
\ No newline at end of file
+        return self.target.ctrl_api
