@@ -76,7 +76,7 @@ class ZC702():
     full_part_name = 'xc7z020clg484-1'
     short_part_name = 'xc7z020'
     dbg_hub_clk_freq = 100e6
-    fpga_sim_ctrl = [FPGASimCtrl.UART_ZYNQ, FPGASimCtrl.VIVADO_VIO]
+    fpga_sim_ctrl = [FPGASimCtrl.VIVADO_VIO]
 
 class ULTRA96():
     """
@@ -96,9 +96,22 @@ class ZC706():
     """
     clk_pin = ['H9', 'G9']
     clk_io = 'LVDS'
-    clk_freq = 200
+    clk_freq = 200e6
     board_part = 'xilinx.com:zc706:part0:1.4'
     full_part_name = 'xc7z045ffg900-2'
     short_part_name = 'xc7z045'
     dbg_hub_clk_freq = 100e6
     fpga_sim_ctrl = [FPGASimCtrl.UART_ZYNQ, FPGASimCtrl.VIVADO_VIO]
+
+class ZCU106():
+    """
+    Container to store ZCU106 FPGA board specific properties.
+    """
+    clk_pin = ['H9', 'G9']
+    clk_io = 'LVDS'
+    clk_freq = 125e6
+    board_part = 'xilinx.com:zcu106:part0:2.5'
+    full_part_name = 'xczu7ev-ffvc1156-2-e'
+    short_part_name = 'xczu7ev'
+    dbg_hub_clk_freq = 100e6
+    fpga_sim_ctrl = [FPGASimCtrl.UART_ZYNQ, FPGASimCtrl.VIVADO_VIO]
