@@ -1,13 +1,13 @@
+# general imports
 import numpy as np
 import os
 import csv
-import time
-
-
-from anasymod.utils.VCD_parser import ParseVCD
 from typing import Union
 
+# anasymod imports
 from anasymod.targets import CPUTarget, FPGATarget
+from anasymod.utils.VCD_parser import ParseVCD
+
 
 class Probe():
     """
@@ -334,7 +334,7 @@ class ProbeVCD(Probe):
             self.probe_caches[run_num] = run_cache
 
         #check complete name of emu_time_probe
-        matching = [s for s in self._probes() if 'emu_time' in s]
+        matching = [s for s in self._probes() if self.target.str_cfg.time_probe.name in s]
         if len(matching) == 1:
             emu_time_probe = matching[0]
         else:
@@ -442,7 +442,11 @@ class ProbeVCD(Probe):
 
             if signal in [""]:
                 raise ValueError("No data found for signal:{0}".format(name))
-            return np.array([cycle_cnt, signal], dtype='O')
+
+            if signal == self.target.str_cfg.time_probe.name:
+                return np.array([cycle_cnt, signal], dtype='O')
+            else:
+                return np.array([cycle_cnt, signal], dtype='O')
 
         else:
             # parse all signals into run_cache
@@ -454,7 +458,13 @@ class ProbeVCD(Probe):
                 cycle_cnt = [i[0] for i in signal_dict[key]['cv']]
                 net = signal_dict[key]['nets'][0]
                 name = net['hier'] + '.' + net['name']
-                data[name] = np.array([cycle_cnt,signal], dtype='O')
+                if signal_dict[key]['nets'][0]['name'] == self.target.str_cfg.time_probe.name:
+                    #convert binary representation on time signal to integer and scale according to precision set in prj
+                    dt_scale = self.target.prj_cfg.cfg.dt_scale
+                    signal_scaled = [int(x, 2) * dt_scale for x in signal]
+                    data[name] = np.array([cycle_cnt, signal_scaled], dtype='O')
+                else:
+                    data[name] = np.array([cycle_cnt, signal], dtype='O')
                 data[name].setflags(write=False)
 
             if signal in [""]:
